@@ -3,13 +3,12 @@ require 'spec_helper'
 describe 'neutron::agents::l3' do
 
   let :pre_condition do
-    "class { 'neutron': rabbit_password => 'passw0rd' }"
+    "class { 'neutron': }"
   end
 
   let :default_params do
     { :package_ensure     => 'present',
       :enabled            => true,
-      :debug              => false,
       :interface_driver   => 'neutron.agent.linux.interface.OVSInterfaceDriver',
       :ha_enabled         => false,
       :ha_vrrp_auth_type  => 'PASS',
@@ -36,12 +35,11 @@ describe 'neutron::agents::l3' do
     it { is_expected.to contain_class('neutron::params') }
 
     it 'configures l3_agent.ini' do
-      is_expected.to contain_neutron_l3_agent_config('DEFAULT/debug').with_value(p[:debug])
+      is_expected.to contain_neutron_l3_agent_config('DEFAULT/debug').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_l3_agent_config('DEFAULT/interface_driver').with_value(p[:interface_driver])
       is_expected.to contain_neutron_l3_agent_config('DEFAULT/gateway_external_network_id').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_l3_agent_config('DEFAULT/handle_internal_only_routers').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_l3_agent_config('DEFAULT/metadata_port').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_l3_agent_config('DEFAULT/send_arp_for_ha').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_l3_agent_config('DEFAULT/periodic_interval').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_l3_agent_config('DEFAULT/periodic_fuzzy_delay').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_l3_agent_config('DEFAULT/enable_metadata_proxy').with_value('<SERVICE DEFAULT>')
@@ -121,7 +119,8 @@ describe 'neutron::agents::l3' do
   context 'on Debian platforms' do
     let :facts do
       @default_facts.merge(test_facts.merge({
-         :osfamily => 'Debian'
+         :osfamily => 'Debian',
+         :os       => { :name  => 'Debian', :family => 'Debian', :release => { :major => '8', :minor => '0' } },
       }))
     end
 
@@ -141,7 +140,8 @@ describe 'neutron::agents::l3' do
     let :facts do
       @default_facts.merge(test_facts.merge({
          :osfamily               => 'RedHat',
-         :operatingsystemrelease => '7'
+         :operatingsystemrelease => '7',
+         :os       => { :name  => 'CentOS', :family => 'RedHat', :release => { :major => '7', :minor => '0' } },
       }))
     end
 
