@@ -97,7 +97,8 @@ describe 'neutron::agents::ovn_metadata' do
   context 'on Debian platforms' do
     let :facts do
       @default_facts.merge(test_facts.merge(
-        { :osfamily => 'Debian' }
+        { :osfamily => 'Debian',
+          :os       => { :name  => 'Debian', :family => 'Debian', :release => { :major => '8', :minor => '0' } } }
       ))
     end
 
@@ -113,7 +114,8 @@ describe 'neutron::agents::ovn_metadata' do
     let :facts do
       @default_facts.merge(test_facts.merge({
          :osfamily => 'RedHat',
-         :operatingsystemrelease => '7'
+         :operatingsystemrelease => '7',
+         :os       => { :name  => 'CentOS', :family => 'RedHat', :release => { :major => '7', :minor => '0' } },
       }))
     end
 
