@@ -14,6 +14,8 @@ describe 'neutron::config' do
       { :server_config => config_hash }
     end
 
+    it { is_expected.to contain_class('neutron::deps') }
+
     it 'configures arbitrary neutron-config configurations' do
       is_expected.to contain_neutron_config('DEFAULT/foo').with_value('fooValue')
       is_expected.to contain_neutron_config('DEFAULT/bar').with_value('barValue')
@@ -62,6 +64,7 @@ describe 'neutron::config' do
         :metering_agent_config => config_hash,
         :vpnaas_agent_config   => config_hash,
         :l2gw_agent_config     => config_hash,
+        :bgp_dragent_config    => config_hash,
       }
     end
 
@@ -107,6 +110,12 @@ describe 'neutron::config' do
       is_expected.to contain_neutron_l2gw_agent_config('DEFAULT/baz').with_ensure('absent')
     end
 
+    it 'configures arbitrary bgp_dragent_config configurations' do
+      is_expected.to contain_neutron_bgp_dragent_config('DEFAULT/foo').with_value('fooValue')
+      is_expected.to contain_neutron_bgp_dragent_config('DEFAULT/bar').with_value('barValue')
+      is_expected.to contain_neutron_bgp_dragent_config('DEFAULT/baz').with_ensure('absent')
+    end
+
   end
 
   shared_examples_for 'neutron_plugin_config' do
