@@ -8,8 +8,7 @@ describe 'neutron::plugins::ml2::cisco' do
      }
      class { 'neutron::server': }
      class { 'neutron':
-      rabbit_password => 'passw0rd',
-      core_plugin     => 'neutron.plugins.ml2.plugin.Ml2Plugin' }"
+      core_plugin     => 'ml2' }"
   end
 
   let :default_params do
@@ -51,7 +50,8 @@ describe 'neutron::plugins::ml2::cisco' do
       let :facts do
         @default_facts.merge(test_facts.merge({
            :osfamily               => 'RedHat',
-           :operatingsystemrelease => '7'
+           :operatingsystemrelease => '7',
+           :os       => { :name  => 'CentOS', :family => 'RedHat', :release => { :major => '7', :minor => '0' } },
         }))
       end
 
