@@ -49,7 +49,8 @@ describe 'neutron::plugins::ml2::mellanox' do
       let :facts do
         OSDefaults.get_facts.merge(test_facts.merge({
            :osfamily               => 'RedHat',
-           :operatingsystemrelease => '7'
+           :operatingsystemrelease => '7',
+           :os       => { :name  => 'CentOS', :family => 'RedHat', :release => { :major => '7', :minor => '0' } },
         }))
       end
 
