@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'neutron::server' do
 
   let :pre_condition do
-    "class { 'neutron': rabbit_password => 'passw0rd' }
+    "class { 'neutron': }
      class { '::neutron::keystone::authtoken':
        password => 'passw0rd',
      }"
@@ -77,8 +77,10 @@ describe 'neutron::server' do
       is_expected.to contain_neutron_config('DEFAULT/agent_down_time').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/enable_new_agents').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/router_scheduler_driver').with_value(p[:router_scheduler_driver])
-      is_expected.to contain_neutron_config('qos/notification_drivers').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_middleware/enable_proxy_headers_parsing').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_oslo__middleware('neutron_config').with(
+        :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+      )
+      is_expected.to contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('<SERVICE DEFAULT>')
     end
 
     context 'with manage_service as false' do
@@ -140,17 +142,6 @@ describe 'neutron::server' do
       end
     end
 
-    context 'with state_path and lock_path parameters' do
-      before :each do
-        params.merge!(:state_path => 'state_path',
-                      :lock_path  => 'lock_path' )
-      end
-      it 'should override state_path and lock_path from base class' do
-        is_expected.to contain_neutron_config('DEFAULT/state_path').with_value(p[:state_path])
-        is_expected.to contain_neutron_config('oslo_concurrency/lock_path').with_value(p[:lock_path])
-      end
-    end
-
     context 'with allow_automatic_l3agent_failover in neutron.conf' do
       it 'should configure allow_automatic_l3agent_failover' do
         is_expected.to contain_neutron_config('DEFAULT/allow_automatic_l3agent_failover').with_value('<SERVICE DEFAULT>')
@@ -163,15 +154,6 @@ describe 'neutron::server' do
       end
     end
 
-    context 'with qos_notification_drivers parameter' do
-      before :each do
-        params.merge!(:qos_notification_drivers => 'message_queue')
-      end
-      it 'should configure qos_notification_drivers' do
-        is_expected.to contain_neutron_config('qos/notification_drivers').with_value('message_queue')
-      end
-    end
-
     context 'with network_auto_schedule in neutron.conf' do
       it 'should configure network_auto_schedule' do
         is_expected.to contain_neutron_config('DEFAULT/network_auto_schedule').with_value('<SERVICE DEFAULT>')
@@ -223,7 +205,9 @@ describe 'neutron::server' do
         params.merge!({:enable_proxy_headers_parsing => true })
       end
 
-      it { is_expected.to contain_neutron_config('oslo_middleware/enable_proxy_headers_parsing').with_value(true) }
+      it { is_expected.to contain_oslo__middleware('neutron_config').with(
+        :enable_proxy_headers_parsing => true,
+      )}
     end
 
     context 'when running neutron-api in wsgi' do
@@ -232,7 +216,7 @@ describe 'neutron::server' do
       end
 
       let :pre_condition do
-        "class { 'neutron': rabbit_password => 'passw0rd' }
+        "class { 'neutron': }
          include ::apache
          class { '::neutron::keystone::authtoken':
            password => 'passw0rd',
@@ -263,23 +247,74 @@ describe 'neutron::server' do
         )
       end
     end
+
+    context 'with ovs_integration_bridge set' do
+      before :each do
+        params.merge!({:ovs_integration_bridge => 'br-int' })
+      end
+
+      it { is_expected.to contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('br-int') }
+    end
+
   end
 
-  shared_examples_for 'VPNaaS, FWaaS and LBaaS package installation' do
+  shared_examples_for 'VPNaaS and FWaaS package installation' do
     before do
       params.merge!(
         :ensure_vpnaas_package => true,
         :ensure_fwaas_package  => true,
-        :ensure_lbaas_package  => true
       )
     end
     it 'should install *aaS packages' do
-      is_expected.to contain_package('neutron-lbaasv2-agent')
       is_expected.to contain_package('neutron-fwaas')
       is_expected.to contain_package('neutron-vpnaas-agent')
     end
   end
 
+  shared_examples_for 'neutron server dynamic routing debian' do
+    before do
+      params.merge!( :ensure_dr_package => true )
+    end
+
+    it 'should install dynamic routing package' do
+      is_expected.to contain_package('neutron-dynamic-routing')
+      is_expected.not_to contain_package('neutron-bgp-dragent')
+    end
+  end
+
+  shared_examples_for 'neutron server dynamic routing redhat' do
+    before do
+      params.merge!( :ensure_dr_package => true )
+    end
+
+    it 'should install bgp dragent package' do
+      is_expected.not_to contain_package('neutron-dynamic-routing')
+      is_expected.to contain_package('neutron-bgp-dragent')
+    end
+  end
+
+  shared_examples_for 'neutron server lbaas debian' do
+    before do
+      params.merge!( :ensure_lbaas_package => true )
+    end
+
+    it 'should install lbaas package' do
+      is_expected.to contain_package('neutron-lbaas')
+      is_expected.not_to contain_package('neutron-lbaasv2-agent')
+    end
+  end
+
+  shared_examples_for 'neutron server lbaas redhat' do
+    before do
+      params.merge!( :ensure_lbaas_package => true )
+    end
+
+    it 'should install lbaasv2-agent package' do
+      is_expected.not_to contain_package('neutron-lbaas')
+      is_expected.to contain_package('neutron-lbaasv2-agent')
+    end
+  end
+
   shared_examples_for 'a neutron server without database synchronization' do
     before do
       params.merge!(
@@ -294,7 +329,8 @@ describe 'neutron::server' do
   context 'on Debian platforms' do
     let :facts do
       @default_facts.merge(test_facts.merge({
-         :osfamily       => 'Debian',
+         :osfamily => 'Debian',
+         :os       => { :name  => 'Debian', :family => 'Debian', :release => { :major => '8', :minor => '0' } },
       }))
     end
 
@@ -305,6 +341,8 @@ describe 'neutron::server' do
 
     it_configures 'a neutron server'
     it_configures 'a neutron server without database synchronization'
+    it_configures 'neutron server dynamic routing debian'
+    it_configures 'neutron server lbaas debian'
   end
 
   context 'on RedHat platforms' do
@@ -312,6 +350,7 @@ describe 'neutron::server' do
       @default_facts.merge(test_facts.merge({
           :osfamily               => 'RedHat',
           :operatingsystemrelease => '7',
+          :os       => { :name  => 'CentOS', :family => 'RedHat', :release => { :major => '7', :minor => '0' } },
       }))
     end
 
@@ -321,5 +360,7 @@ describe 'neutron::server' do
 
     it_configures 'a neutron server'
     it_configures 'a neutron server without database synchronization'
+    it_configures 'neutron server dynamic routing redhat'
+    it_configures 'neutron server lbaas redhat'
   end
 end
