@@ -22,7 +22,7 @@ require 'spec_helper'
 
 describe 'neutron::services::fwaas' do
   let :pre_condition do
-    "class { 'neutron': rabbit_password => 'passw0rd' }
+    "class { 'neutron': }
      include ::neutron::agents::l3"
   end
 
@@ -55,6 +55,13 @@ describe 'neutron::services::fwaas' do
     it 'configures driver in fwaas_driver.ini' do
       is_expected.to contain_neutron_fwaas_service_config('fwaas/driver').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_fwaas_service_config('fwaas/enabled').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_fwaas_service_config('fwaas/agent_version').with_value('<SERVICE DEFAULT>')
+    end
+
+    it 'configures driver in neutron.conf' do
+      is_expected.to contain_neutron_config('fwaas/driver').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_config('fwaas/enabled').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_config('fwaas/agent_version').with_value('<SERVICE DEFAULT>')
     end
   end
 
@@ -62,7 +69,8 @@ describe 'neutron::services::fwaas' do
     let :facts do
       @default_facts.merge(test_facts.merge(
         { :osfamily        => 'Debian',
-          :operatingsystem => 'Ubuntu'
+          :operatingsystem => 'Ubuntu',
+          :os       => { :name  => 'Ubuntu', :family => 'Debian', :release => { :major => '16', :minor => '04' } },
         }
       ))
     end
@@ -72,7 +80,7 @@ describe 'neutron::services::fwaas' do
     it 'installs neutron fwaas package' do
       is_expected.to contain_package('neutron-fwaas').with(
         :ensure => 'present',
-        :tag    => 'openstack',
+        :tag    => ['neutron-package', 'openstack'],
         :name   => 'python-neutron-fwaas',
       )
     end
@@ -82,7 +90,8 @@ describe 'neutron::services::fwaas' do
     let :facts do
       @default_facts.merge(test_facts.merge(
         { :osfamily        => 'Debian',
-          :operatingsystem => 'Debian'
+          :operatingsystem => 'Debian',
+          :os       => { :name  => 'Debian', :family => 'Debian', :release => { :major => '8', :minor => '0' } },
         }
       ))
     end
@@ -92,7 +101,7 @@ describe 'neutron::services::fwaas' do
     it 'installs neutron fwaas package' do
       is_expected.to contain_package('neutron-fwaas').with(
         :ensure => 'present',
-        :tag    => 'openstack',
+        :tag    => ['neutron-package', 'openstack'],
         :name   => 'python-neutron-fwaas',
       )
     end
@@ -101,7 +110,8 @@ describe 'neutron::services::fwaas' do
   context 'on Debian platforms with VPNaaS' do
     let :facts do
       @default_facts.merge(test_facts.merge({
-         :osfamily => 'Debian'
+         :osfamily => 'Debian',
+         :os       => { :name  => 'Debian', :family => 'Debian', :release => { :major => '8', :minor => '0' } },
       }))
     end
 
@@ -114,7 +124,7 @@ describe 'neutron::services::fwaas' do
     it 'installs neutron vpnaas agent package' do
       is_expected.to contain_package('neutron-vpn-agent').with(
         :ensure => 'present',
-        :tag    => 'openstack'
+        :tag    => ['neutron-package', 'openstack'],
       )
     end
   end
@@ -123,7 +133,8 @@ describe 'neutron::services::fwaas' do
     let :facts do
       @default_facts.merge(test_facts.merge({
          :osfamily               => 'RedHat',
-         :operatingsystemrelease => '7'
+         :operatingsystemrelease => '7',
+         :os       => { :name  => 'CentOS', :family => 'RedHat', :release => { :major => '7', :minor => '0' } },
       }))
     end
 
