@@ -23,7 +23,7 @@ describe 'neutron::services::l2gw' do
       password => 'passw0rd',
      }
      class { 'neutron::server': }
-     class { 'neutron': rabbit_password => 'passw0rd' }"
+     class { 'neutron': }"
   end
 
   let :default_params do
