@@ -23,7 +23,7 @@ require 'spec_helper'
 describe 'neutron::services::lbaas' do
 
   let :default_params do
-    { :service_providers => '<SERVICE DEFAULT>'}
+    {}
   end
 
   shared_examples_for 'neutron lbaas service plugin' do
@@ -60,26 +60,13 @@ describe 'neutron::services::lbaas' do
         end
       end
     end
-
-    context 'with multiple service providers' do
-      let :params do
-        default_params.merge(
-          { :service_providers => ['provider1', 'provider2'] }
-        )
-      end
-
-      it 'configures neutron.conf' do
-        is_expected.to contain_neutron_lbaas_service_config(
-          'service_providers/service_provider'
-        ).with_value(['provider1', 'provider2'])
-      end
-    end
   end
 
   context 'on Debian platforms' do
     let :facts do
       @default_facts.merge({
-        :osfamily  => 'Debian'
+        :osfamily  => 'Debian',
+        :os       => { :name  => 'Debian', :family => 'Debian', :release => { :major => '8', :minor => '0' } },
       })
     end
 
@@ -94,7 +81,8 @@ describe 'neutron::services::lbaas' do
     let :facts do
       @default_facts.merge({
         :osfamily => 'RedHat',
-        :operatingsystemrelease => '7'
+        :operatingsystemrelease => '7',
+        :os       => { :name  => 'CentOS', :family => 'RedHat', :release => { :major => '7', :minor => '0' } },
       })
     end
 
